@@ -28,7 +28,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QGraphicsWidget>
 #include <QPainter>
 #include <QSvgRenderer>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 
 // KDE
 
