@@ -21,7 +21,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "touch.h"
 
 // Qt
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 #include <QWidget>
 #include <QCoreApplication>
 #include <QMouseEvent>
